@@ -2,6 +2,7 @@
 
 import asyncio
 import pytest
+import pytest_asyncio
 from google.protobuf.struct_pb2 import Struct
 from google.protobuf.wrappers_pb2 import BytesValue
 
@@ -18,7 +19,7 @@ def broker():
     )
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 async def subscriber(broker):
     client = AsyncLocalSubscriber(broker=broker, queue_names=['test'])
     async with client:
